Glossary
========

.. glossary::
    meta-stable
        A level is considered meta-stable if there's no line that has this level as the upper state. This means
        that these levels can not be reached by absorbing a photon and are only reached when decaying.

    synapps
        simple radiative transport code for supernovae. Please refer to `Synapps <https://c3.lbl.gov/es/>`_ for more
        information